.. _reference:

Reference
=========

Below are some reference materials for ytree, including API documentation
for all available functionality and a log of changes from each stable
release.

.. toctree::
   :maxdepth: 2

   api_reference
   changelog
